<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\BimFile;
use App\Services\File\BimService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

class GlendaleController extends Controller
{
    private function parseInput(Request $request): array
    {
        $data = $request->input('data', '');

        $inputArr = json_decode_arr($data);

        Log::info('glendale callback params:', $inputArr);

        return $inputArr;
    }

    /**
     * 葛兰岱尔模型转换通知回调处理
     * @param \Illuminate\Http\Request $request
     * @param \App\Services\File\BimService $bimService
     * @return \Illuminate\Http\JsonResponse
     */
    public function callback(Request $request, BimService $bimService)
    {
        $arr = $this->parseInput($request);
        $lightweightName = $arr['LightweightName'] ?? '';

        $bimFile = BimFile::where("bim_file_id", $lightweightName)->gelendale()->firstOrFail();

        $bimService->storeBimInfo($bimFile);

        return $this->success($arr);
    }

    /**
     * 葛兰岱尔模型数据同步通知回调处理
     * @param \Illuminate\Http\Request $request
     * @param \App\Services\File\BimService $bimService
     * @return \Illuminate\Http\JsonResponse
     */
    public function syncCallback(Request $request, BimService $bimService)
    {
        $arr = $this->parseInput($request);
        $lightweightName = $arr['LightweightName'] ?? '';

        return $this->success($arr);
    }
}
