<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\API;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/

Route::post("/login", [API\AuthController::class, "login"]);
Route::post("/send-forget-password-email", [API\AuthController::class, "sendForgetPasswordEmail"]);
Route::post("/reset-password", [API\AuthController::class, "resetPassword"]);
//Route::post("register/company-user", [API\UserController::class, "registerCompanyUser"]);
Route::post("register/company", [API\CompanyController::class, "registerCompany"]);
Route::post("company-file-upload", [API\FileController::class, "companyUpload"]);
//暂时为免登录
Route::post("model-upload", [API\FileController::class, "modelUpload"])->name("file.modelUpload");
Route::get("file/download/{uuid}/share-file", [API\FileController::class, "downloadShareFile"])
    ->name("file.download-share-file");

// Route::get("test/test", [API\TestController::class, "test"]);//测试用预留
Route::post("glendale/callback", [API\GlendaleController::class, "callback"])->name('glendale.callback');
Route::post("glendale/sync-callback", [API\GlendaleController::class, "syncCallback"])->name('glendale.sync-callback');
Route::post("bim/preview-image", [API\BimController::class, "setPreviewImage"]);

Route::middleware(['auth:sanctum','account.limit'])->group(function () {
    //公共权限
    Route::post("/logout", [API\AuthController::class, "logout"]);
    Route::get("user/details", [API\UserController::class, 'details']);
    Route::get("user-items", [API\UserController::class, 'publicSearch']);
    Route::get("asset-tree",[API\AssetController::class, 'tree']);
    Route::get("asset/{asset_id}/report",[API\AssetController::class, 'report']);
    Route::get("asset-items",[API\AssetController::class, "publicSearch"]);
    Route::get("asset-group-items",[API\AssetGroupController::class, "publicSearch"]);
    Route::get("requirement-group-items",[API\RequirementGroupController::class, "publicSearch"]);
    Route::get("requirement-items",[API\RequirementController::class, "publicSearch"]);
    Route::get("role-items",[API\RoleController::class, "publicSearch"]);
    Route::get("project-by-asset",[API\ProjectController::class, "byAsset"]);
    Route::get("project-items",[API\ProjectController::class, "publicSearch"]);
    Route::get("project/{project}/project-requirement-items",[API\ProjectController::class, "publicSearchRequirement"]);
    Route::get("project/{project}/project-team-items", [API\TeamMemberController::class, "publicSearch"]);
    Route::get("task-items",[API\TaskController::class, "publicSearch"]);
    Route::get("project-tree",[API\ProjectController::class, 'tree']);
    Route::get("plan-by-assets", [API\PlanController::class, "byAssets"]);
    Route::get("notification", [API\NotificationController::class, "index"]);
    Route::get("notification/unread", [API\NotificationController::class, "unread"]);
    Route::post("notification/mark-as-read", [API\NotificationController::class, "markAsRead"]);
    Route::get("naming-rule-enabled", [API\NameRuleController::class, "enabled"]);
    Route::get("container-report", [API\ContainerController::class, "containerReport"]);
    Route::get("library", [API\LibraryController::class, "index"]);
    Route::get('container', [API\ContainerController::class, "index"]);
    Route::get("action/{object_type}/history/{object_id}", [API\ActionController::class, "history"]);
    Route::get("company-items", [API\CompanyController::class, "publicSearch"]);
    Route::get("department-items", [API\DepartmentController::class, "publicSearch"]);
    Route::get("container-linkage/{library_id}", [API\ContainerController::class, "linkage"]);
    Route::get("folder-open", [API\FolderController::class, "open"]);
    Route::get("folder-tree/{object_type}/{object_id}", [API\FolderController::class, "tree"]);
    Route::get("file/{object_type}/{object_id}", [API\FileController::class, "byObject"]);
    Route::get("folder/file-version-tree/{object_type}/{object_id}", [API\FolderController::class, "versionFileTreeByObject"]);
    Route::get("project-asset-tree/{project_id}", [API\ProjectController::class, "projectAssetTree"]);
    Route::get("project-requirementGroups-tree/{asset_id}", [API\ProjectController::class, "projectRequirementGroupsTree"]);
    Route::get("project/{project}/not-link-asset-requirement", [API\ProjectController::class, "notLinkAssetRequirement"]);
    Route::get("library-linkage/{type}", [API\LibraryController::class, "linkage"]);
    Route::get("project/{project}/latest-dynamic", [API\ProjectController::class, "latestDynamic"]);
    Route::get("file-upload-progress/{request_id}", [API\FileController::class, "uploadProgress"]);
    Route::get('plan/{plan_id}/not-link-asset-requirement',[API\PlanController::class, "notLinkAssetRequirement"]);
    Route::get("department-user-index",[API\DepartmentController::class,"departmentUserIndex"]);
    Route::get("all-last-dynamic",[API\ActionController::class,"lastDynamic"]);
    Route::get("approval-items",[API\ApprovalController::class, "publicSearch"]);
    Route::post("file-cos-token",[API\FileController::class, "getCOSToken"])->name('file.cos.token');
    Route::post("naming-rule/{name_rule}/parse", [API\NameRuleController::class, "parse"]);


    // Allow access only to admin role
    Route::middleware(['permission', 'role.super-admin', 'system.operation-log'])->group(function () {
        Route::apiResource("company", API\CompanyController::class)->only([
            'store','destroy','show'
        ]);


//        Route::patch("user/userInfo/{user_id}",[API\UserController::class, 'updateUserInfo'])->name('user.updateUserInfo');

        Route::post("company/action",[API\CompanyController::class,"action"])->name("company.action");
        Route::get('system-operation-log', [API\SystemOperationLogController::class, 'index'])->name("system-operation-log.index");

    });

    Route::middleware(['permission', 'system.operation-log'])->group(function() {


        Route::apiResources([
            'asset-group' => API\AssetGroupController::class,
            'asset' => API\AssetController::class,
            'requirement-group' => API\RequirementGroupController::class,
            'requirement' => API\RequirementController::class,
            'project' => API\ProjectController::class,
            'plan' => API\PlanController::class,
            'roles' => API\RoleController::class,
            'custom-field' => API\CustomFieldController::class,
            'naming-rule' => API\NameRuleController::class,
            'task' => API\TaskController::class,
//            'library' => API\LibraryController::class,
            'department' => API\DepartmentController::class,
            'user' => API\UserController::class,
//            'container' => API\ContainerController::class,
            'approval-flow'  => API\ApprovalFlowController::class,
            'approval' => API\ApprovalController::class,
        ]);
        Route::apiResource("company", API\CompanyController::class)->only([
            'index', 'show', 'update'
        ]);

        Route::post ("department/userList", [API\DepartmentController::class, 'userList'])->name("department.userList");
        Route::post ("company/structure", [API\CompanyController::class, 'structure'])->name("company.structure");
        Route::post ("department/structure", [API\DepartmentController::class, 'structure'])->name("department.structure");

        Route::apiResource("library", API\LibraryController::class)->only([
            'store','update','destroy','show'
        ]);

        Route::apiResource("container", API\ContainerController::class)->only([
            'store','update','destroy','show'
        ]);

        Route::get("config", [API\ConfigController::class, "index"])->name("config.index");
        Route::post("config-setting", [API\ConfigController::class, "setting"])->name("config.setting");
        Route::get("config/message-notification-setting", [API\ConfigController::class, "messageNotificationSetting"])
            ->name("config.message-notification-setting");
        Route::post("config/message-notification-setting", [API\ConfigController::class, "storeMessageNotificationSetting"])
            ->name("config.store-message-notification-setting");

        Route::get("permission", [API\PermissionController::class, 'groupPermissions'])->name("permission.group-permission");
        Route::get("permission/menu", [API\PermissionController::class, 'menuPermissions'])->name("permission.menu");



        Route::get("role/{role}/permission", [API\RoleController::class, "permissions"])->name("role.permissions");
        Route::put("role/{role}/assign-permission", [API\RoleController::class, "assignPermissions"])->name("role.assign-permissions");
        Route::put("role/{role}/assign-menus-permission", [API\RoleController::class, "assignMenusPermissions"])->name("role.assign-menus-permissions");
        Route::put("user/{user}/assign-role", [API\UserController::class, "assignRole"])->name("user.assign-role");
        Route::get("role/{role}/menus", [API\RoleController::class, "menus"])->name("role.menus");



        Route::post("approval/{approval}/action", [API\ApprovalController::class, 'action'])->name("approval.action");
        Route::patch("approval-cancel", [API\ApprovalController::class, 'cancel'])->name("approval.cancel");
        Route::post("approval/{approval}/copy-container-file", [API\ApprovalController::class, "copyContainerFile"])
            ->name("approval.copy-container-file");


        Route::get("asset/{asset}/dynamic", [API\AssetController::class, "dynamic"])->name("asset.dynamic");



        Route::patch("requirement/{requirement_id}/close",[API\RequirementController::class, 'close'])->name('requirement.close');
        Route::patch("requirement/{requirement_id}/start",[API\RequirementController::class, 'start'])->name('requirement.start');
        //Route::get("requirement/{asset_id}/asset", [API\RequirementController::class, "byAsset"])->name("requirement.byAsset");
        Route::patch("requirement/{plan_id}/plan", [API\RequirementController::class, "linkPlan"])->name("requirement.linkPlan");
        Route::patch("requirement/plan/unlink", [API\RequirementController::class, "unlinkPlan"])->name("requirement.unlinkPlan");
        Route::get("requirement-export", [API\RequirementController::class, "export"])->name("requirement.export");
        Route::post("requirement-import", [API\RequirementController::class, "import"])->name("requirement.import");


        Route::get("project/{project}/dynamic", [API\ProjectController::class, "dynamic"])->name("project.dynamic");
        Route::get("project/{project}/kanban", [API\ProjectController::class, "kanban"])->name("project.kanban");
        Route::get("project/{project}/group-view", [API\ProjectController::class, "groupView"])->name("project.group-view");
        Route::get("project/{project}/export-group-view", [API\ProjectController::class, "exportGroupView"])->name("project.export-group-view");
        Route::get("project/{project}/gantt", [API\ProjectController::class, "gantt"])->name("project.gantt");
        Route::get("project/gantt/export", [API\ProjectController::class, "ganttExport"])->name("project.gantt-export");
        Route::get("project/{project}/print-kanban", [API\ProjectController::class, "printKanban"])->name("project.print-kanban");
        Route::get("project/kanban/export", [API\ProjectController::class, "kanbanExport"])->name("project.kanban-export");
        Route::patch("project/{project}/closed", [API\ProjectController::class, "closed"])->name("project.closed");
        Route::patch("project/{project}/start", [API\ProjectController::class, "start"])->name("project.start");
        Route::patch("project/{project}/pause", [API\ProjectController::class, "pause"])->name("project.pause");
        Route::patch("project/{project}/done", [API\ProjectController::class, "done"])->name("project.done");
        Route::patch("project/{project}/postpone", [API\ProjectController::class, "postpone"])
            ->name("project.postpone");
        Route::patch("project/{project}/link-requirement", [API\ProjectController::class, "linkRequirement"])
            ->name("project.link-requirement");
        Route::patch("project/{project}/unlink-requirement", [API\ProjectController::class, "unlinkRequirement"])
            ->name("project.unlink-requirement");
        Route::patch("project/{project}/link-requirement-by-plan", [API\ProjectController::class, "linkRequirementByPlan"])
            ->name("project.link-requirement-by-plan");
        Route::patch("project/{project_id}/update-link-assets", [API\ProjectController::class, "updateLinkAssets"])
            ->name("project.update-link-assets");

        Route::get("project/{project}/plan", [API\ProjectController::class, "plan"])
            ->name("project.plan"); //项目关联计划
        Route::get("project/{project}/requirement", [API\ProjectController::class, "requirement"])
            ->name("project.requirement"); //项目需求
        Route::get("project-4s", [API\ProjectController::class, "project4s"])
            ->name("project.4s");
        Route::get("project-iot", [API\ProjectController::class, "iot"])
            ->name("project.iot");
        Route::get("project-iot/{siteName}/{deviceNumber}", [API\ProjectController::class, "fetchDeviceObjects"])
            ->name("project.fetchDeviceObjects");
        Route::get("project-iot/objects-values/{siteName}/{dataKey}", [API\ProjectController::class, "fetchObjectsValueMulti"])
            ->name("project.fetchObjectsValueMulti");

//        Route::get("project/{project}/not-link-asset-requirement", [API\ProjectController::class, "notLinkAssetRequirement"])
//            ->name("project.not-link-asset-requirement"); //项目未关联的资产需求


        Route::patch("task/{task}/closed", [API\TaskController::class, "closed"])->name("task.closed");
        Route::patch("task/{task}/start", [API\TaskController::class, "start"])->name("task.start");
        Route::patch("task/{task}/pause", [API\TaskController::class, "pause"])->name("task.pause");
        Route::patch("task/{task}/done", [API\TaskController::class, "done"])->name("task.done");
        Route::patch("task/{task}/cancel", [API\TaskController::class, "cancel"])->name("task.cancel");
        Route::patch("task/{task}/wait", [API\TaskController::class, "wait"])->name("task.wait");
        Route::post("task-batch-create", [API\TaskController::class, "batchStore"])->name("task.batch-store");
        Route::patch("task/{task}/assign", [API\TaskController::class, "assign"])->name("task.assign");
        Route::post("task/{task}/container", [API\TaskController::class, "linkContainer"])->name("task.link-container");
        Route::delete("task-container/{task_container}", [API\TaskController::class, "unlinkContainer"])->name("task.unlink-container");
        Route::get("task/{task}/container-to-be-linked", [API\TaskController::class, "containerToBeLinked"])->name("task.container-to-be-linked");
        Route::get("task-export", [API\TaskController::class, "export"])->name("task.export");
        Route::post("task-import", [API\TaskController::class, "import"])->name("task.import");

        Route::post("user/user-batch-create", [API\UserController::class, "batchStore"])->name("user.batch-create");
        Route::put("user/status/{status}", [API\UserController::class, "status"])->name("user.status");
        //Route::patch("user/update-info", [API\UserController::class, "updateInfo"])->name("user.updateInfo");

        Route::get("custom-field-group", [API\CustomFieldController::class, "groups"])->name("custom-field.groups");
        Route::get("custom-field-group/naming-rule", [API\CustomFieldController::class, "nameRuleGroups"])->name("custom-field.nameRuleGroups");


        Route::post("naming-rule/{naming_rule}/combination", [API\NameRuleController::class, "combinationSetting"])
            ->name("naming-rule.combination-setting");
        Route::get("naming-rule/{naming_rule}/combination/show", [API\NameRuleController::class, "combinationShow"])
            ->name("naming-rule.combination-show");
        Route::post("naming-rule/{name_rule}/autoname", [API\NameRuleController::class, "autoname"])
            ->name("name-rule.autoname");

        Route::get("naming-rule/export/custom", [API\NameRuleController::class, "exportCustom"])
            ->name("name-rule.export-custom");
        Route::post("naming-rule/import/custom", [API\NameRuleController::class, "importCustom"])
            ->name("name-rule.import-custom");


        Route::get("team-member/{project}", [API\TeamMemberController::class, "members"])->name("team-member.list");
        Route::delete("team-member/{team_member}", [API\TeamMemberController::class, "destroy"])->name("team-member.destroy");
        Route::post("team-member/{project}/manage", [API\TeamMemberController::class, "manageMembers"])->name("team-member.manage-members");


        Route::post("folder", [API\FolderController::class, "store"])->name("folder.store");
        Route::get("folder/{folder}", [API\FolderController::class, "show"])->name("folder.show");
        Route::patch("folder/{folder}", [API\FolderController::class, "update"])->name("folder.update");
        Route::delete("folder/{folder}", [API\FolderController::class, "destroy"])->name("folder.destroy");
//        Route::get("folder-open", [API\FolderController::class, "open"])->name("folder.open");
//        Route::get("folder/file-version-tree/{object_type}/{object_id}", [API\FolderController::class, "versionFileTreeByObject"])
//            ->name("folder.file-version-tree-by-object");
        Route::patch("folder/{folder}/change-name", [API\FolderController::class, "changeName"])->name("folder.change-name");
        Route::get("folder/search/folder-file", [API\FolderController::class, "search"])->name("folder.search-folder-file");
        Route::patch("folder/apply-naming/{folder_id}/{naming_id}", [API\FolderController::class, "applyNaming"])->name("folder.apply-naming");


        Route::post("requirement/batch", [API\RequirementController::class, "batchStore"])->name("requirement.batchStore");

        //Route::get("requirement-by-assets", [API\RequirementController::class, "byAssets"])->name("requirement.by-assets");

        //Route::get("project-tree/{project_id}", [API\ProjectController::class, "treeIndex"])->name("project.project-tree");
//        Route::get("project-asset-tree/{project_id}", [API\ProjectController::class, "projectAssetTree"])->name("project.project-asset-tree");
//        Route::get("project-requirementGroups-tree/{asset_id}", [API\ProjectController::class, "projectRequirementGroupsTree"])->name("project.project-requirementGroups-tree");


        Route::get("project-link-requirements-group/{project_id}",[API\ProjectController::class, "requirementsLinkGroup"])->name("project.link-requirements-group");

        Route::post("action/{object_type}/comment/{object_id}", [API\ActionController::class, "comment"])->name("action.comment");
        Route::patch("action/{action}/comment", [API\ActionController::class, "updateComment"])->name("action.update-comment");

        Route::post("file-upload", [API\FileController::class, "upload"])->name("file.upload");

//        Route::get("file/{object_type}/{object_id}", [API\FileController::class, "byObject"])->name("file.by-object");
        Route::post("file/{file}/download", [API\FileController::class, "download"])->name("file.download");
        Route::post("file/download-zip", [API\FileController::class, "downloadZip"])->name("file.download-zip");
        Route::get("file/download-all-latest/{object_type}/{object_id}", [API\FileController::class, "downloadAllLatest"])
            ->name("file.download-all-latest");


        Route::patch("file/{file}/change-name", [API\FileController::class, "changeName"])->name("file.change-name");
        Route::delete("file/{file}/destroy", [API\FileController::class, "destroy"])->name("file.destroy");
        Route::post("file/keep-directory-upload", [API\FileController::class, "keepDirectoryUpload"])->name("file.keep-directory-upload");
        Route::delete("file/{file}/hide", [API\FileController::class, "hide"])->name("file.hide");
        Route::get("file-bim-view/{file}", [API\FileController::class, "bimView"])->name("file.bim-view");
        Route::get("file/models", [API\FileController::class, "models"])->name("file.models");
        Route::get("file/model-history", [API\FileController::class, "modelHistory"])->name("file.model-history");
        Route::get("file/{fileId}", [API\FileController::class, "detail"])->name("file.detail");
        Route::apiResource("file", API\FileController::class)->only([
            'update'
        ]);


        Route::get("bim/multiple-views", [API\BimController::class, "multipleViews"])->name("bim.multiple-views");
        Route::post('bim/combine', [API\BimController::class, "combine"])->name("bim.combine");
        Route::put('bim/combine/{combineId}', [API\BimController::class, "combineUpdate"])->name("bim.combine-update");
        Route::get('bim/combined-list', [API\BimController::class, "combinedList"])->name("bim.combined-list");
        Route::delete('bim/combine/{combineId}', action: [API\BimController::class, "combineDelete"])->name("bim.combine-delete");
        Route::get("bim/comparison", [API\BimController::class, "getComparison"])->name("bim.comparison");

        Route::get("container-attachments", [API\ContainerController::class, "attachments"])->name("container.attachments");

        Route::post("share-file", [API\ShareFileController::class, "store"])->name("share-file.store");
        Route::delete("share-file/{share_file}", [API\ShareFileController::class, "destroy"])
            ->name("share-file.destroy");
        Route::get("share-file/{object_type}/{object_id}", [API\ShareFileController::class, "byObject"])
            ->name("share-file.by-object");
    });
});
